@@ -31,9 +31,3 @@ def get_downloaded_files(
         for file in get_files_from(podcast_directory)
         if podcast_files_filter(file) and is_directory_file(file)
     )
-
-
-def get_last_downloaded(
-    podcast_files_filter: Callable[[str], bool], podcast_directory: str
-) -> str:
-    return next(get_downloaded_files(podcast_files_filter, podcast_directory), None)
