@@ -22,6 +22,4 @@ def load_configuration_file(file_path: str) -> dict:
 
 
 def parse_argv(parser: ArgumentParser, args=None):
-    return {key: value
-            for key, value in vars(parser.parse_args(args)).items()
-            if value}
+    return {key: value for key, value in vars(parser.parse_args(args)).items() if value}
